DeviceInstalledAppsPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • DeviceInstalledAppsPlatform
Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAppInfo(String bundleId) → Future<AppInfo>
getApps(String bundleIdPrefix, bool includeSystemApps, bool includeIcon, List<String> permissions, bool shouldHasAllPermissions) → Future<List<AppInfo>>
getAppsBundleIds(String bundleIdPrefix, bool includeSystemApps, List<String> permissions, bool shouldHasAllPermissions) → Future<List<String>>
getSystemApps(String bundleIdPrefix, bool includeIcon, List<String> permissions, bool shouldHasAllPermissions) → Future<List<AppInfo>>
isSystemApp(String bundleId) → Future<bool?>
launchApp(String bundleId) → Future<bool?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openAppSetting(String bundleId) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ DeviceInstalledAppsPlatform
getter/setter pair